.. @+leo-ver=5-thin
.. @+node:peckj.20130503092808.1688: * @file leo.plugins.rst
.. @@language rest
plugins Package
===============

:mod:`plugins` Package
----------------------

.. automodule:: leo.plugins
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FileActions` Module
-------------------------

.. automodule:: leo.plugins.FileActions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`active_path` Module
-------------------------

.. automodule:: leo.plugins.active_path
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`add_directives` Module
----------------------------

.. automodule:: leo.plugins.add_directives
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`at_folder` Module
-----------------------

.. automodule:: leo.plugins.at_folder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`at_produce` Module
------------------------

.. automodule:: leo.plugins.at_produce
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`at_view` Module
---------------------

.. automodule:: leo.plugins.at_view
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`attrib_edit` Module
-------------------------

.. automodule:: leo.plugins.attrib_edit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`backlink` Module
----------------------

.. automodule:: leo.plugins.backlink
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`baseNativeTree` Module
----------------------------

.. automodule:: leo.plugins.baseNativeTree
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`bibtex` Module
--------------------

.. automodule:: leo.plugins.bibtex
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`bigdash` Module
---------------------

.. automodule:: leo.plugins.bigdash
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`bookmarks` Module
-----------------------

.. automodule:: leo.plugins.bookmarks
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`bzr_qcommands` Module
---------------------------

.. automodule:: leo.plugins.bzr_qcommands
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`chapter_hoist` Module
---------------------------

.. automodule:: leo.plugins.chapter_hoist
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`codewisecompleter` Module
-------------------------------

.. automodule:: leo.plugins.codewisecompleter
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`colorize_headlines` Module
--------------------------------

.. automodule:: leo.plugins.colorize_headlines
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`contextmenu` Module
-------------------------

.. automodule:: leo.plugins.contextmenu
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ctagscompleter` Module
----------------------------

.. automodule:: leo.plugins.ctagscompleter
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cursesGui` Module
-----------------------

.. automodule:: leo.plugins.cursesGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`datenodes` Module
-----------------------

.. automodule:: leo.plugins.datenodes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`debugger_pudb` Module
---------------------------

.. automodule:: leo.plugins.debugger_pudb
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dragdropgoodies` Module
-----------------------------

.. automodule:: leo.plugins.dragdropgoodies
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dtest` Module
-------------------

.. automodule:: leo.plugins.dtest
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`dump_globals` Module
--------------------------

.. automodule:: leo.plugins.dump_globals
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`empty_leo_file` Module
----------------------------

.. automodule:: leo.plugins.empty_leo_file
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`enable_gc` Module
-----------------------

.. automodule:: leo.plugins.enable_gc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`expfolder` Module
-----------------------

.. automodule:: leo.plugins.expfolder
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`free_layout` Module
-------------------------

.. automodule:: leo.plugins.free_layout
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ftp` Module
-----------------

.. automodule:: leo.plugins.ftp
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`geotag` Module
--------------------

.. automodule:: leo.plugins.geotag
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gitarchive` Module
------------------------

.. automodule:: leo.plugins.gitarchive
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`graphcanvas` Module
-------------------------

.. automodule:: leo.plugins.graphcanvas
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gtkDialogs` Module
------------------------

.. automodule:: leo.plugins.gtkDialogs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`gtkGui` Module
--------------------

.. automodule:: leo.plugins.gtkGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`import_cisco_config` Module
---------------------------------

.. automodule:: leo.plugins.import_cisco_config
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`initinclass` Module
-------------------------

.. automodule:: leo.plugins.initinclass
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interact` Module
----------------------

.. automodule:: leo.plugins.interact
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`internal_ipkernel` Module
-------------------------------

.. automodule:: leo.plugins.internal_ipkernel
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ipython` Module
---------------------

.. automodule:: leo.plugins.ipython
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ironPythonGui` Module
---------------------------

.. automodule:: leo.plugins.ironPythonGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`jinjarender` Module
-------------------------

.. automodule:: leo.plugins.jinjarender
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leoOPML` Module
---------------------

.. automodule:: leo.plugins.leoOPML
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leo_interface` Module
---------------------------

.. automodule:: leo.plugins.leo_interface
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leo_pdf` Module
---------------------

.. automodule:: leo.plugins.leo_pdf
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leo_to_html` Module
-------------------------

.. automodule:: leo.plugins.leo_to_html
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leo_to_rtf` Module
------------------------

.. automodule:: leo.plugins.leo_to_rtf
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leocursor` Module
-----------------------

.. automodule:: leo.plugins.leocursor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leofeeds` Module
----------------------

.. automodule:: leo.plugins.leofeeds
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leofts` Module
--------------------

.. automodule:: leo.plugins.leofts
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leomail` Module
---------------------

.. automodule:: leo.plugins.leomail
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leomylyn` Module
----------------------

.. automodule:: leo.plugins.leomylyn
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leoremote` Module
-----------------------

.. automodule:: leo.plugins.leoremote
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`leoscreen` Module
-----------------------

.. automodule:: leo.plugins.leoscreen
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`lineNumbers` Module
-------------------------

.. automodule:: leo.plugins.lineNumbers
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`livecode` Module
-------------------------

.. automodule:: leo.plugins.livecode
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`macros` Module
--------------------

.. automodule:: leo.plugins.macros
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`maximizeNewWindows` Module
--------------------------------

.. automodule:: leo.plugins.maximizeNewWindows
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mime` Module
------------------

.. automodule:: leo.plugins.mime
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mnplugins` Module
-----------------------

.. automodule:: leo.plugins.mnplugins
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_autosave` Module
--------------------------

.. automodule:: leo.plugins.mod_autosave
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_framesize` Module
---------------------------

.. automodule:: leo.plugins.mod_framesize
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_http` Module
----------------------

.. automodule:: leo.plugins.mod_http
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_leo2ascd` Module
--------------------------

.. automodule:: leo.plugins.mod_leo2ascd
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_read_dir_outline` Module
----------------------------------

.. automodule:: leo.plugins.mod_read_dir_outline
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_scripting` Module
---------------------------

.. automodule:: leo.plugins.mod_scripting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_speedups` Module
--------------------------

.. automodule:: leo.plugins.mod_speedups
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_tempfname` Module
---------------------------

.. automodule:: leo.plugins.mod_tempfname
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`mod_timestamp` Module
---------------------------

.. automodule:: leo.plugins.mod_timestamp
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`multifile` Module
-----------------------

.. automodule:: leo.plugins.multifile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nav_qt` Module
--------------------

.. automodule:: leo.plugins.nav_qt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nested_splitter` Module
-----------------------------

.. automodule:: leo.plugins.nested_splitter
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`niceNosent` Module
------------------------

.. automodule:: leo.plugins.niceNosent
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nodeActions` Module
-------------------------

.. automodule:: leo.plugins.nodeActions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nodediff` Module
----------------------

.. automodule:: leo.plugins.nodediff
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`nodetags` Module
----------------------

.. automodule:: leo.plugins.nodetags
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`nodewatch` Module
-----------------------

.. automodule:: leo.plugins.nodewatch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`notebook` Module
----------------------

.. automodule:: leo.plugins.notebook
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`open_shell` Module
------------------------

.. automodule:: leo.plugins.open_shell
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`outline_export` Module
----------------------------

.. automodule:: leo.plugins.outline_export
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`paste_as_headlines` Module
--------------------------------

.. automodule:: leo.plugins.paste_as_headlines
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pluginsTest` Module
-------------------------

.. automodule:: leo.plugins.pluginsTest
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plugins_menu` Module
--------------------------

.. automodule:: leo.plugins.plugins_menu
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`pretty_print` Module
--------------------------

.. automodule:: leo.plugins.pretty_print
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`projectwizard` Module
---------------------------

.. automodule:: leo.plugins.projectwizard
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`python_terminal` Module
---------------------------

.. automodule:: leo.plugins.python_terminal
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`qtGui` Module
-------------------

.. automodule:: leo.plugins.qtGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`qt_main` Module
---------------------

.. automodule:: leo.plugins.qt_main
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`qt_quicksearch` Module
----------------------------

.. automodule:: leo.plugins.qt_quicksearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`qtframecommands` Module
-----------------------------

.. automodule:: leo.plugins.qtframecommands
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`quickMove` Module
-----------------------

.. automodule:: leo.plugins.quickMove
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`quicksearch` Module
-------------------------

.. automodule:: leo.plugins.quicksearch
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`quit_leo` Module
----------------------

.. automodule:: leo.plugins.quit_leo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`read_only_nodes` Module
-----------------------------

.. automodule:: leo.plugins.read_only_nodes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`redirect_to_log` Module
-----------------------------

.. automodule:: leo.plugins.redirect_to_log
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rss` Module
-----------------

.. automodule:: leo.plugins.rss
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rst3` Module
------------------

.. automodule:: leo.plugins.rst3
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`run_nodes` Module
-----------------------

.. automodule:: leo.plugins.run_nodes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`screen_capture` Module
----------------------------

.. automodule:: leo.plugins.screen_capture
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`screencast` Module
------------------------

.. automodule:: leo.plugins.screencast
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`screenshots` Module
-------------------------

.. automodule:: leo.plugins.screenshots
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`script_io_to_body` Module
-------------------------------

.. automodule:: leo.plugins.script_io_to_body
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`scripts_menu` Module
--------------------------

.. automodule:: leo.plugins.scripts_menu
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`setHomeDirectory` Module
------------------------------

.. automodule:: leo.plugins.setHomeDirectory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sftp` Module
------------------

.. automodule:: leo.plugins.sftp
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`slideshow` Module
-----------------------

.. automodule:: leo.plugins.slideshow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`spydershell` Module
-------------------------

.. automodule:: leo.plugins.spydershell
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`startfile` Module
-----------------------

.. automodule:: leo.plugins.startfile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stickynotes` Module
-------------------------

.. automodule:: leo.plugins.stickynotes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`stickynotes_plus` Module
------------------------------

.. automodule:: leo.plugins.stickynotes_plus
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`swing_gui` Module
-----------------------

.. automodule:: leo.plugins.swing_gui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`systray` Module
---------------------

.. automodule:: leo.plugins.systray
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`testRegisterCommand` Module
---------------------------------

.. automodule:: leo.plugins.testRegisterCommand
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`textnode` Module
----------------------

.. automodule:: leo.plugins.textnode
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`threadutil` Module
------------------------

.. automodule:: leo.plugins.threadutil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`timestamp` Module
------------------------

.. automodule:: leo.plugins.timestamp
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tkGui` Module
-------------------

.. automodule:: leo.plugins.tkGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`todo` Module
------------------

.. automodule:: leo.plugins.todo
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tomboy_import` Module
---------------------------

.. automodule:: leo.plugins.tomboy_import
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`trace_gc_plugin` Module
-----------------------------

.. automodule:: leo.plugins.trace_gc_plugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`trace_keys` Module
------------------------

.. automodule:: leo.plugins.trace_keys
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`trace_tags` Module
------------------------

.. automodule:: leo.plugins.trace_tags
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`valuespace` Module
------------------------

.. automodule:: leo.plugins.valuespace
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`viewrendered` Module
--------------------------

.. automodule:: leo.plugins.viewrendered
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`viewrendered2` Module
--------------------------

.. automodule:: leo.plugins.viewrendered2
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`vim` Module
-----------------

.. automodule:: leo.plugins.vim
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`word_count` Module
------------------------

.. automodule:: leo.plugins.word_count
    :members:
    :undoc-members:
    :show-inheritance:
    
:mod:`wikiview` Module
------------------------

.. automodule:: leo.plugins.wikiview
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`word_export` Module
-------------------------

.. automodule:: leo.plugins.word_export
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`wxGui` Module
-------------------

.. automodule:: leo.plugins.wxGui
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xemacs` Module
--------------------

.. automodule:: leo.plugins.xemacs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xml_edit` Module
----------------------

.. automodule:: leo.plugins.xml_edit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`xsltWithNodes` Module
---------------------------

.. automodule:: leo.plugins.xsltWithNodes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`zenity_file_dialogs` Module
---------------------------------

.. automodule:: leo.plugins.zenity_file_dialogs
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    leo.plugins.pygeotag

.. @-leo
